
/* Generated data (by glib-mkenums) */

#if !defined(__JSON_GLIB_INSIDE__) && !defined(JSON_COMPILATION)
#error "Only <json-glib/json-glib.h> can be included directly."
#endif

#ifndef __JSON_ENUM_TYPES_H__
#define __JSON_ENUM_TYPES_H__

#include <glib-object.h>

G_BEGIN_DECLS

/* enumerations from "../json-glib/json-parser.h" */
GType json_parser_error_get_type (void) G_GNUC_CONST;
#define JSON_TYPE_PARSER_ERROR (json_parser_error_get_type())

/* enumerations from "../json-glib/json-reader.h" */
GType json_reader_error_get_type (void) G_GNUC_CONST;
#define JSON_TYPE_READER_ERROR (json_reader_error_get_type())

/* enumerations from "../json-glib/json-types.h" */
GType json_node_type_get_type (void) G_GNUC_CONST;
#define JSON_TYPE_NODE_TYPE (json_node_type_get_type())

G_END_DECLS

#endif /* !__JSON_ENUM_TYPES_H__ */

/* Generated data ends here */

